@@ -1,7 +1,7 @@
 from collections import defaultdict
 from datetime import date, datetime, time, timedelta
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Set, Union, cast
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Set, Type, Union, cast
 
 from starlette.middleware import Middleware as StarletteMiddleware
 from starlette.middleware.cors import CORSMiddleware
@@ -16,6 +16,7 @@ from starlite.asgi import (
 )
 from starlite.config import AppConfig, CacheConfig, OpenAPIConfig
 from starlite.config.logging import get_logger_placeholder
+from starlite.connection import Request, WebSocket
 from starlite.datastructures.state import State
 from starlite.exceptions import ImproperlyConfiguredException, ValidationException
 from starlite.handlers.asgi import asgi
@@ -100,8 +101,8 @@ class HandlerIndex(TypedDict):
     """Full route paths to the route handler."""
     handler: "RouteHandlerType"
     """Route handler instance."""
-    qualname: str
-    """Qualname of the handler"""
+    identifier: str
+    """Unique identifier of the handler. Either equal to the 'name' attribute or the __str__ value of the handler."""
 
 
 class HandlerNode(TypedDict):
@@ -117,8 +118,8 @@ class Starlite(Router):
     __slots__ = (
         "_init",
         "_registered_routes",
-        "_route_mapping",
         "_route_handler_index",
+        "_route_mapping",
         "_static_paths",
         "after_exception",
         "after_shutdown",
@@ -143,10 +144,12 @@ class Starlite(Router):
         "openapi_schema",
         "plain_routes",
         "plugins",
+        "request_class",
         "route_map",
         "state",
         "static_files_config",
         "template_engine",
+        "websocket_class",
     )
 
     def __init__(
@@ -179,6 +182,7 @@ class Starlite(Router):
         openapi_config: Optional[OpenAPIConfig] = DEFAULT_OPENAPI_CONFIG,
         parameters: Optional["ParametersMap"] = None,
         plugins: Optional[List["PluginProtocol"]] = None,
+        request_class: Optional[Type["Request"]] = None,
         response_class: Optional["ResponseType"] = None,
         response_cookies: Optional["ResponseCookies"] = None,
         response_headers: Optional["ResponseHeadersMap"] = None,
@@ -186,6 +190,7 @@ class Starlite(Router):
         static_files_config: Optional[Union["StaticFilesConfig", List["StaticFilesConfig"]]] = None,
         tags: Optional[List[str]] = None,
         template_config: Optional["TemplateConfig"] = None,
+        websocket_class: Optional[Type["WebSocket"]] = None,
     ) -> None:
         """The Starlite application.
 
@@ -244,6 +249,8 @@ class Starlite(Router):
             parameters: A mapping of [Parameter][starlite.params.Parameter] definitions available to all
                 application paths.
             plugins: List of plugins.
+            request_class: An optional subclass of [Request][starlite.connection.request.Request] to use for
+                http connections.
             response_class: A custom subclass of [starlite.response.Response] to be used as the app's default response.
             response_cookies: A list of [Cookie](starlite.datastructures.Cookie] instances.
             response_headers: A string keyed dictionary mapping [ResponseHeader][starlite.datastructures.ResponseHeader]
@@ -256,6 +263,8 @@ class Starlite(Router):
             static_files_config: An instance or list of [StaticFilesConfig][starlite.config.StaticFilesConfig]
             tags: A list of string tags that will be appended to the schema of all route handlers under the application.
             template_config: An instance of [TemplateConfig][starlite.config.TemplateConfig]
+            websocket_class: An optional subclass of [WebSocket][starlite.connection.websocket.WebSocket] to use for
+                websocket connections.
         """
         self._registered_routes: Set[BaseRoute] = set()
         self._route_mapping: Dict[str, List[BaseRoute]] = defaultdict(list)
@@ -296,6 +305,7 @@ class Starlite(Router):
             openapi_config=openapi_config,
             parameters=parameters or {},
             plugins=plugins or [],
+            request_class=request_class,
             response_class=response_class,
             response_cookies=response_cookies or [],
             response_headers=response_headers or {},
@@ -304,6 +314,7 @@ class Starlite(Router):
             static_files_config=static_files_config or [],
             tags=tags or [],
             template_config=template_config,
+            websocket_class=websocket_class,
         )
         for handler in on_app_init or []:
             config = handler(config)
@@ -320,13 +331,15 @@ class Starlite(Router):
         self.cors_config = config.cors_config
         self.csrf_config = config.csrf_config
         self.debug = config.debug
+        self.logging_config = config.logging_config
         self.on_shutdown = config.on_shutdown
         self.on_startup = config.on_startup
         self.openapi_config = config.openapi_config
         self.plugins = config.plugins
+        self.request_class = config.request_class or Request
         self.static_files_config = config.static_files_config
         self.template_engine = config.template_config.to_engine() if config.template_config else None
-        self.logging_config = config.logging_config
+        self.websocket_class = config.websocket_class or WebSocket
 
         super().__init__(
             after_request=config.after_request,
@@ -442,7 +455,7 @@ class Starlite(Router):
 
             handler_index = app.get_handler_index_by_name("my-handler")
 
-            # { "path": ["/"], "handler" ... }
+            # { "paths": ["/"], "handler" ... }
             ```
         Args:
             name: A route handler unique name.
@@ -454,12 +467,11 @@ class Starlite(Router):
         if not handler:
             return None
 
-        qualname = self._get_handler_qualname(handler)
-
-        routes = self._route_mapping[qualname]
+        identifier = handler.name or str(handler)
+        routes = self._route_mapping[identifier]
         paths = sorted(unique([route.path for route in routes]))
 
-        return HandlerIndex(handler=handler, paths=paths, qualname=qualname)
+        return HandlerIndex(handler=handler, paths=paths, identifier=identifier)
 
     def route_reverse(self, name: str, **path_parameters: Any) -> Optional[str]:
         """Receives a route handler name, path parameter values and returns an
@@ -470,7 +482,7 @@ class Starlite(Router):
             from starlite import Starlite, get
 
 
-            @get("/group/{group_id:int}/user/{user_id:int}", name="get_memebership_details")
+            @get("/group/{group_id:int}/user/{user_id:int}", name="get_membership_details")
             def get_membership_details(group_id: int, user_id: int) -> None:
                 pass
 
@@ -499,7 +511,7 @@ class Starlite(Router):
         output: List[str] = []
 
         routes = sorted(
-            self._route_mapping[handler_index["qualname"]], key=lambda r: len(r.path_parameters), reverse=True
+            self._route_mapping[handler_index["identifier"]], key=lambda r: len(r.path_parameters), reverse=True
         )
         passed_parameters = set(path_parameters.keys())
 
@@ -601,7 +613,8 @@ class Starlite(Router):
         self._configure_route_map_node(route, current_node)
         return current_node
 
-    def _get_route_handlers(self, route: BaseRoute) -> List["RouteHandlerType"]:
+    @staticmethod
+    def _get_route_handlers(route: BaseRoute) -> List["RouteHandlerType"]:
         """Retrieve handler(s) as a list for given route."""
         route_handlers: List["RouteHandlerType"] = []
         if isinstance(route, (WebSocketRoute, ASGIRoute)):
@@ -611,14 +624,6 @@ class Starlite(Router):
 
         return route_handlers
 
-    def _get_handler_qualname(self, handler: "RouteHandlerType") -> str:
-        """Retrieves __qualname__ for passed route handler."""
-        handler_fn = cast("AnyCallable", handler.fn)
-        if hasattr(handler_fn, "__qualname__"):
-            return handler_fn.__qualname__
-
-        return type(handler_fn).__qualname__
-
     def _store_handler_to_route_mapping(self, route: BaseRoute) -> None:
         """Stores the mapping of route handlers to routes and to route handler
         names.
@@ -632,18 +637,15 @@ class Starlite(Router):
         route_handlers = self._get_route_handlers(route)
 
         for handler in route_handlers:
-            qualname = self._get_handler_qualname(handler)
-            self._route_mapping[qualname].append(route)
-
-            name = handler.name or self._get_handler_qualname(handler)
-
-            if (
-                name in self._route_handler_index
-                and self._get_handler_qualname(self._route_handler_index[name]) != qualname
+            if handler.name in self._route_handler_index and str(self._route_handler_index[handler.name]) != str(
+                handler
             ):
-                raise ImproperlyConfiguredException(f"route handler names must be unique - {name} is not unique.")
-
-            self._route_handler_index[name] = handler
+                raise ImproperlyConfiguredException(
+                    f"route handler names must be unique - {handler.name} is not unique."
+                )
+            identifier = handler.name or str(handler)
+            self._route_mapping[identifier].append(route)
+            self._route_handler_index[identifier] = handler
 
     def _configure_route_map_node(self, route: BaseRoute, node: RouteMapNode) -> None:
         """Set required attributes and route handlers on route_map tree
