@@ -9,7 +9,7 @@ from starlite.middleware.exceptions import ExceptionHandlerMiddleware
 from starlite.middleware.logging import LoggingMiddleware, LoggingMiddlewareConfig
 from starlite.middleware.rate_limit import RateLimitConfig, RateLimitMiddleware
 
-__all__ = [
+__all__ = (
     "AbstractAuthenticationMiddleware",
     "AuthenticationResult",
     "CSRFMiddleware",
@@ -21,4 +21,4 @@ __all__ = [
     "MiddlewareProtocol",
     "RateLimitConfig",
     "RateLimitMiddleware",
-]
+)
